.. _spkg__cibuildwheel_local_b:

_cibuildwheel_local_b: Non-Python dependencies of packages for which we build platform wheels, side B
=====================================================================================================


Type
----

optional


Dependencies
------------

- :ref:`spkg_ccache`
- :ref:`spkg_cmr`
- :ref:`spkg_eclib`
- :ref:`spkg_flint`
- :ref:`spkg_gap`
- :ref:`spkg_gap_packages`
- :ref:`spkg_givaro`
- :ref:`spkg_gmp`
- :ref:`spkg_gp2c`
- :ref:`spkg_gsl`
- :ref:`spkg_iml`
- :ref:`spkg_lcalc`
- :ref:`spkg_libgd`
- :ref:`spkg_libpng`
- :ref:`spkg_linbox`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_meataxe`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfi`
- :ref:`spkg_mpfr`
- :ref:`spkg_ntl`
- :ref:`spkg_pari`
- :ref:`spkg_polytopes_db`
- :ref:`spkg_sympow`
- :ref:`spkg_xeus_gp`


Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i _cibuildwheel_local_b


